==> maradns-3.5.0022.tar.xz: maradns-3.5.0022/CONTRIBUTING.md <==
Please read this ticket before opening up a new issue:

* Feature requests will be ignored. I am not getting paid enough
  for MaraDNS to develop features (actually, I am not getting paid for
  MaraDNS at all; in fact, it’s a net loss for me because I pay for
  maradns.samiam.org hosting out of pocket)
* MaraDNS is not bug-for-bug identical to BIND when resolving poorly
  configured domains. See https://github.com/samboy/MaraDNS/issues/31
* Asking for anything specified in an RFC that came out after 2010 is
  a feature request; MaraDNS was frozen in 2010 and I am not getting paid
  enough to be current with newer RFCs.
* Distribution specific issues should not be filed here.  Please contact
  the support team for the Linux distribution you are using if using a
  package from that distribution to install MaraDNS.
* Support requests should not be filed here. RTFM—read the f!@#$
  manual! If the manual does not answer your question, STFW: Search the !@#$
  web! If that does not answer your question, UTSL: Use the Source Luke.
* Legitimate bug reports may or may not be handled.
* Security bug reports will probably be handled. If the issue is one
  that you wish to keep confidential, please open up a ticket here
  in Github; make sure your Github profile has contact information
  or include contact information in the bug report. But really, you
  won’t find that kind of security bug in MaraDNS: MaraDNS has been
  around for nearly two decades and no one has ever found a bug in it
  which should have been kept confidential before I patched it (see
  http://maradns.samiam.org/security.html )
* Spam disguised as a MaraDNS issue will be deleted. If the ticket does
  not mention MaraDNS, I will assume the ticket is robot-generated spam,
  and will both delete and report the ticket.

I have a mortgage to pay and a family to care for (I had neither when
I started MaraDNS back in 2001). That in mind, I need to devote time
either to my family or to activities which will help support my family. I
plain simply have very little free time (it took me nearly a month to
find three hours free to watch the latest Star Wars movie), and I am not
about to waste that free time implementing whatever feature request you
want for free. TANSTAAFL: There ain’t no such thing as a free lunch.

Thank you for your understanding.

==> maradns-3.5.0034.tar.xz: maradns-3.5.0034/CONTRIBUTING.md <==
Please read this before opening up a new issue:

* Feature requests might be ignored. I am not getting paid enough
  for MaraDNS to develop features (actually, I am not getting paid for
  MaraDNS at all; in fact, it’s a net loss for me because I pay for
  maradns.samiam.org hosting out of pocket)
* MaraDNS is not bug-for-bug identical to BIND when resolving poorly
  configured domains. See https://github.com/samboy/MaraDNS/issues/31
* Asking for anything specified in an RFC that came out after 2010 is
  a feature request.  While I do add new features from time to time,
  post-2010 RFC requests are like other features.
* Distribution specific issues should not be filed here.  Please contact
  the support team for the Linux distribution you are using if using a
  package from that distribution to install MaraDNS.
* Legitimate bug reports may or may not be handled.
* Security bug reports will probably be handled. If the issue is one
  that you wish to keep confidential, please open up a ticket here
  in Github; make sure your Github profile has contact information
  or include contact information in the bug report. But really, you
  won’t find that kind of security bug in MaraDNS: MaraDNS has been
  around for nearly two decades and no one has ever found a bug in it
  which should have been kept confidential before I patched it (see
  http://maradns.samiam.org/security.html )
* Spam will be deleted. If a post does not mention MaraDNS or any
  other relevant content, I will assume the post is robot-generated spam,
  and will both delete and report it.

Thank you for your understanding.
